# CREATE-DISCORD-BOT

An opinionated cli-tool to bootstrap your discord bot code!

#### FEATURES

- Support for code with/without cogs.
- .env file support for keys and .gitignore to hide it.
- Bot code pre-built with a ping function to get you started!

## Usage

placeholder

## Built using

- Python
- Discord.py
- argparse
